const fs = require("fs");
const parser = require("@babel/parser");
const enforceFunctionComponents = require("./lib/rules/enforce-function-components");
const enforceNoConsole = require("./lib/rules/enforce-no-console");
const enforceDescriptiveVariables = require("./lib/rules/enforce-descriptive-variables");
const enforceReduxActionNaming = require("./lib/rules/enforce-redux-action-naming");
const enforceFunctionLength = require("./lib/rules/enforce-function-length");
const enforceUseEffectDependencies = require("./lib/rules/enforce-useeffect-dependencies");
const enforceStateInitialization = require("./lib/rules/enforce-state-initialization");
const enforceNoInlineStyles = require("./lib/rules/enforce-no-inline-styles");
const enforceComponentLength = require ("./lib/rules/enforce-component-length")

const analyzeFile = (filePath) => {
  const code = fs.readFileSync(filePath, "utf8");

  const ast = parser.parse(code, {
    sourceType: "module",
    plugins: ["jsx", "classProperties"],
  });

  console.log(`\nAnalyzing ${filePath}...`);
  enforceFunctionComponents(ast, filePath);
  enforceNoConsole(ast, filePath);
  enforceDescriptiveVariables(ast, filePath);
  enforceReduxActionNaming(ast, filePath);
  enforceFunctionLength(ast, filePath);
  enforceUseEffectDependencies(ast, filePath);
  enforceStateInitialization(ast, filePath);
  enforceNoInlineStyles (ast, filePath);
  enforceComponentLength (ast, filePath);
};

const args = process.argv.slice(2);
if (args.length === 0) {
  console.error("No file specified. Usage: node index.js <file>");
  process.exit(1);
}

const filePath = args[0];
if (!fs.existsSync(filePath)) {
  console.error(`File not found: ${filePath}`);
  process.exit(1);
}

analyzeFile(filePath);
