const fs = require("fs");
const path = require("path");
const chalk = require("chalk");
const rules = require("./rules");

function isJavaScriptFile(filePath) {
  return /\.(js|jsx)$/.test(filePath);
}

function lintFile(filePath) {
  const content = fs.readFileSync(filePath, "utf-8");
  const issues = [];

  for (const rule of rules) {
    const result = rule.check(content);
    if (result) {
      issues.push(...result);
    }
  }

  return issues;
}

function runLinter(targetPath) {
  if (!fs.existsSync(targetPath)) {
    console.error(chalk.red(`Error: ${targetPath} does not exist.`));
    process.exit(1);
  }

  const stats = fs.statSync(targetPath);
  const files = stats.isDirectory()
    ? fs.readdirSync(targetPath).map((file) => path.join(targetPath, file))
    : [targetPath];

  for (const file of files) {
    if (!isJavaScriptFile(file)) continue;

    const issues = lintFile(file);
    if (issues.length > 0) {
      console.log(chalk.yellow(`\nIssues found in ${file}:`));
      issues.forEach((issue, index) => {
        console.log(chalk.red(`${index + 1}. Line ${issue.line}: ${issue.message}`));
        console.log(chalk.cyan(`   Suggestion: ${issue.suggestion}`));
      });
    }
  }

  console.log(chalk.green("\nLinting complete!"));
}

module.exports = { runLinter };
