const chalk = require("chalk");
const { default: traverse } = require("@babel/traverse");

module.exports = function enforceNoInlineStyles(ast, filename) {
  let issues = [];

  traverse(ast, {
    JSXAttribute(path) {
      const { name, value } = path.node;

      // Check if the style attribute is used in JSX and is an object (inline style)
      if (name.name === "style" && value && value.type === "JSXExpressionContainer" && value.expression.type === "ObjectExpression") {
        issues.push({
          line: path.node.loc.start.line,
          message: `Inline styles are used in JSX.`,
          suggestion: `Inline styles should be avoided. Use CSS classes or styled-components instead for better maintainability and performance.`,
        });
      }
    }
  });

  if (issues.length > 0) {
    console.log(chalk.red(`\nIssues in ${filename}:`));
    issues.forEach((issue) => {
      console.log(chalk.yellow(`Line ${issue.line}: ${issue.message}`));
      console.log(chalk.green(`Suggestion: ${issue.suggestion}`));
    });
  }
};
