const chalk = require("chalk");

module.exports = function enforceReduxActionNaming(ast, filename) {
  let issues = [];

  require("@babel/traverse").default(ast, {
    VariableDeclarator(path) {
      const { init, id } = path.node;

      if (
        init &&
        init.type === "StringLiteral" &&
        id.name &&
        /^[A-Z_]+$/.test(id.name) === false
      ) {
        issues.push({
          line: path.node.loc.start.line,
          message: `Redux action type "${id.name}" should be in uppercase and snake_case (e.g., FEATURE_ACTION).`,
        });
      }
    },
  });

  if (issues.length > 0) {
    console.log(chalk.red(`\nIssues in ${filename}:`));
    issues.forEach((issue) => {
      console.log(chalk.yellow(`Line ${issue.line}: ${issue.message}`));
    });
  }
};
