const chalk = require("chalk");
const { default: traverse } = require("@babel/traverse");

module.exports = function enforceUseEffectDependencies(ast, filename) {
  let issues = [];

  traverse(ast, {
    CallExpression(path) {
      // Check if the call expression is for useEffect
      if (
        path.node.callee.name === "useEffect" &&
        path.node.arguments.length > 1 &&
        path.node.arguments[1].type === "ArrayExpression"
      ) {
        const dependencies = path.node.arguments[1].elements;

        // Rule: useEffect hook should have a non-empty dependency array
        if (dependencies.length === 0) {
          issues.push({
            line: path.node.loc.start.line,
            message: `useEffect hook at line ${path.node.loc.start.line} has an empty dependency array.`,
            suggestion: `The "useEffect" hook should list all necessary dependencies in its array, such as component states, props, or other variables. For example, [userData, fetchItems, isAuthenticated].`,
          });
        }
      }
    }
  });

  // Output the issues if any were found
  if (issues.length > 0) {
    console.log(chalk.red(`\nIssues in ${filename}:`));
    issues.forEach((issue) => {
      console.log(chalk.yellow(`Line ${issue.line}: ${issue.message}`));
      console.log(chalk.green(`Suggestion: ${issue.suggestion}`));
    });
  }
};
